@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model;
-$Config::Model::VERSION = '2.089';
+$Config::Model::VERSION = '2.090';
 use strict ;
 use warnings;
 use 5.10.1;
@@ -1190,7 +1190,7 @@ sub load {
     # look for additional model information
     my %model_graft_by_name;
     my %done;  # avoid loading twice the same snippet (where system version may clobber dev version)
-    foreach my $inc (@INC) {
+    foreach my $inc (@INC,'.') {
         foreach my $name ( keys %models_by_name ) {
             my $snippet_path = $name;
             $snippet_path =~ s/::/\//g;
@@ -1252,7 +1252,7 @@ sub _do_model_file {
     get_logger("Model::Loader")->info("load model $load_file");
 
     my $err_msg = '';
-    $load_file = "./$load_file" if $load_file =~ m!^lib/!;
+    $load_file = "./$load_file" if -e $load_file;
     my $model   = do $load_file;
 
     unless ($model) {
@@ -1678,7 +1678,7 @@ Config::Model - Create tools to validate, migrate and edit configuration files
 
 =head1 VERSION
 
-version 2.089
+version 2.090
 
 =head1 SYNOPSIS
 
