@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Annotation;
-$Config::Model::Annotation::VERSION = '2.089';
+$Config::Model::Annotation::VERSION = '2.090';
 use Mouse;
 use English;
 
@@ -134,7 +134,7 @@ sub load {
     my $self = shift;
     my $f    = $self->file;
     return unless -e $f;
-    my $hash = do $f || croak "can't do $f:$!";
+    my $hash = do "./$f" || croak "can't do $f:$!";
     my $root = $self->instance->config_root;
 
     foreach my $path ( keys %$hash ) {
@@ -164,7 +164,7 @@ Config::Model::Annotation - Read and write configuration annotations
 
 =head1 VERSION
 
-version 2.089
+version 2.090
 
 =head1 SYNOPSIS
 
