@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Dumper;
-$Config::Model::Dumper::VERSION = '2.089';
+$Config::Model::Dumper::VERSION = '2.090';
 use Carp;
 use strict;
 use warnings;
@@ -21,11 +21,11 @@ sub new {
 }
 
 sub quote {
-    _quote( qr/(\s|"|\*)/, @_ );
+    _quote( qr/[\s"#*]/, @_ );
 }
 
 sub id_quote {
-    _quote( qr/[\s"\*<>.=#]/, @_ );
+    _quote( qr/[\s"*<>.=#]/, @_ );
 }
 
 sub _quote {
@@ -259,7 +259,7 @@ Config::Model::Dumper - Serialize data of config tree
 
 =head1 VERSION
 
-version 2.089
+version 2.090
 
 =head1 SYNOPSIS
 
