@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Instance;
-$Config::Model::Instance::VERSION = '2.089';
+$Config::Model::Instance::VERSION = '2.090';
 #use Scalar::Util qw(weaken) ;
 use strict;
 
@@ -234,8 +234,6 @@ has config_file => (is  => 'ro', isa => 'Maybe[Str]');
 
 has config_dir => (is  => 'ro', isa => 'Maybe[Str]');
 
-has skip_read => ( is => 'ro', isa => 'Bool', default => 0 );
-
 has tree => (
     is      => 'ro',
     isa     => 'Config::Model::Node',
@@ -247,13 +245,10 @@ has tree => (
 sub reset_config {
     my $self = shift;
 
-    warn "skip_read is deprecated" if $self->skip_read;
-
     return $self->load_node (
         config_class_name => $self->{root_class_name},
         instance          => $self,
         container         => $self,
-        skip_read         => $self->skip_read,
         check             => $self->read_check,
         config_file       => $self->{config_file},
     );
@@ -559,7 +554,7 @@ Config::Model::Instance - Instance of configuration tree
 
 =head1 VERSION
 
-version 2.089
+version 2.090
 
 =head1 SYNOPSIS
 
@@ -634,11 +629,6 @@ supplied if not provided by the configuration model.
 
 Specify which backend to use. See L</write_back ( ... )> for details
 
-=item skip_read
-
-DEPRECATED. When set, configuration files are not read when
-creating configuration tree.
-
 =item check
 
 Specify whether to check value while reading config files. Either:
