@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Node;
-$Config::Model::Node::VERSION = '2.089';
+$Config::Model::Node::VERSION = '2.090';
 use Mouse;
 with "Config::Model::Role::NodeLoader";
 
@@ -93,7 +93,6 @@ sub _config_model {
     my $p    = $self->instance->config_model;
 }
 
-has skip_read  => ( is => 'ro', isa => 'Bool' );
 has check      => ( is => 'ro', isa => 'Str', default => 'yes' );
 has model      => ( is => 'rw', isa => 'HashRef' );
 has needs_save => ( is => 'rw', isa => 'Bool', default => 0 );
@@ -332,7 +331,7 @@ sub init {
         node => $self,
     );
 
-    if ( defined $model->{read_config} and not $self->skip_read ) {
+    if ( defined $model->{read_config} ) {
         $self->read_config_data( check => $self->check );
     }
 
@@ -1202,7 +1201,7 @@ Config::Model::Node - Class for configuration tree node
 
 =head1 VERSION
 
-version 2.089
+version 2.090
 
 =head1 SYNOPSIS
 
