@@ -8,7 +8,7 @@
 #   The GNU Lesser General Public License, Version 2.1, February 1999
 #
 package Config::Model::Value;
-$Config::Model::Value::VERSION = '2.089';
+$Config::Model::Value::VERSION = '2.090';
 use 5.10.1;
 
 use Mouse;
@@ -932,6 +932,12 @@ sub run_code_on_value {
 
     unless ($ret) {
         $logger->debug("run_code_on_value sub returned false");
+        $msg =~ s/\$_/$$value_r/g if defined $$value_r;
+        if ($msg =~ /\$std_value/) {
+            my $std = $self->_fetch_std_no_check ;
+            $msg =~ s/\$std_value/$std/g if defined $std;
+        }
+        $msg .= " (this cannot be fixed with 'cme fix' command)" unless $fix;
         push @$array, $msg unless $apply_fix;
         $self->{nb_of_fixes}++ if ( defined $fix and not $apply_fix );
         $self->apply_fix( $fix, $value_r ) if ( defined $fix and $apply_fix );
@@ -946,8 +952,6 @@ sub run_code_set_on_value {
         my $msg = $w_info->{$label}{msg} || $msg;
         $logger->trace("eval'ed code is: '$code'");
         my $fix = $w_info->{$label}{fix};
-        $msg =~ s/\$_/$$value_r/g if defined $$value_r;
-        $msg .= " (this can be fixed with 'cme fix' command)" if $fix;
 
         my $sub = sub {
             local $_ = shift;
@@ -1445,10 +1449,6 @@ sub _init {
 sub _fetch_std {
     my ( $self, $check ) = @_;
 
-    #$self->_init ;
-
-    my $inst = $self->instance;
-
     if ( not defined $self->{value_type} and $check eq 'yes' ) {
         $self->_value_type_error;
     }
@@ -1480,6 +1480,28 @@ sub _fetch_std {
     return $std_value;
 }
 
+# use when std_value is needed to create error or warning message
+# within a check sub. Using _fetch_std leads to deep recursions
+sub _fetch_std_no_check {
+    my ( $self, $check ) = @_;
+
+    # get stored value or computed value or default value
+    my $std_value;
+
+    eval {
+        $std_value =
+              defined $self->{preset}   ? $self->{preset}
+            : $self->compute_is_default ? $self->compute_obj->compute
+            :                             $self->{default};
+    };
+
+    if ($@) {
+        $logger->debug("eval got error: $@");
+    }
+
+    return $std_value;
+}
+
 my %old_mode = (
     built_in     => 'upstream_default',
     non_built_in => 'non_upstream_default',
@@ -1783,7 +1805,7 @@ Config::Model::Value - Strongly typed configuration value
 
 =head1 VERSION
 
-version 2.089
+version 2.090
 
 =head1 SYNOPSIS
 
@@ -1997,9 +2019,9 @@ C<uniline> values.
 =item warn_if_match
 
 Hash ref. Keys are made of Perl regular expression. The value can
-specify a warning message (leave empty or undefined for default warning
+specify a warning message (leave empty or undefined for a default warning
 message) and instructions to fix the value. A warning is issued
-when the value match the passed regular expression. Valid only for
+when the value matches the passed regular expression. Valid only for
 C<string> or C<uniline> values. The fix instructions is evaluated
 when L<apply_fixes> is called. C<$_> contains the value to fix.
 C<$_> is stored as the new value once the instructions are done.
@@ -2021,7 +2043,8 @@ In the example below, any value matching 'foo' is converted in uppercase:
 The tests are done in alphabetical order. In the example above, C<BAR> test is
 done before C<foo> test.
 
-C<$_> is substituted with the bad value when the message is generated.
+C<$_> is substituted with the bad value when the message is generated. C<$std_value>
+is substituted with the standard value (i.e the preset, computed or default value).
 
 =item warn_unless_match
 
